This is a help function to extract marker names from an object generated by genDataRead, genDataLoad, genDataGetPart or genDataPreprocess.
showSNPnames(data.in, n = 5, from, to)The data as outputted by genDataRead, genDataLoad, genDataGetPart or genDataPreprocess.
Number of names to display or "all" (default: 5).
From which marker to display (optional, default: from the first).
To which marker to display (optional).
A vector with marker names, as read in from map.file or generated dummy names.